#! /usr/bin/perl
#
#  scrubkeds (by Justin Appleby)
#  [justin.appleby@gmail.com]
#
#  This perl script finds occurences of O##, l##, and
#  other bad entries in KEDS data files.  Scrubbed files
#  are written to input_filename.clean
#
#  Usage: ./scrubkeds.pl [filenames]

foreach $arg (@ARGV){
  # set line delimiter -- may be OS specific (such as \r for Mac
  # native files 
  $/ = "\n";

  print "File to parse: $arg \n";
  open (IN, "<$arg") || die "cannot open: $!";
  my @lines = <IN>;
  close(IN);

  my $outfile = $arg . ".clean";
  open(OUT, ">$outfile");

  my $i=0;
  my $rm=0;
  my $errors=0;

  foreach $line (@lines)
  {
      $i++;
      # fix and print back info when malformed data found 
      if ( $line =~ /O\d\d/ ){ 
	  $line =~ s/O(\d\d)/0\1/g;
	  print "Entry $i changed ('O##' found)\n"; 
	  $errors++;
      } 
      if ( $line =~ /l\d\d/ ){ 
	  $line =~ s/l(\d\d)/1\1/g;
	  print "Entry $i changed ('l##' found)\n"; 
	  $errors++;
      } 
      if ( $line =~ /-*]/ ){ 
          $line =~ s/^.*---].*$//g;
          print "Line $i removed (bad data found)\n"; 
	  $rm++;	      
	  next;
      } 
      
      # clean up verbs
      if ( $line =~ /^(\d*\s*\w*\s*\w*\s*[0-9]*)\s*(.*)\n/){
	  $tmp1 = $1;
	  $tmp2 = $2;
	  $tmp2 =~ s/\s+/ /g;
          $tmp2 =~ s/[^A-Za-z() ]*//g;
          $line = "$tmp1\t$tmp2";
      }
      else{ print "Line $i incorrectly formed in input!\n";}

      # Make sure file is tab delimited properly
      $line =~ s/^(\d*)\s*(\w*)\s*(\w*)\s*(\d*)\s*(.*)/\1\t\2\t\3\t\4\t\5\n/g;

      # write to new file
      if ( $line =~ /^\d*\t\w*\t\w*\t\d*\t[^\t]*$/ ){
        print OUT "$line";
      }      
      else { print "Line $i incorrectly formed for output (thus not added)!!\n"; }
  }
  close(OUT);
  print "\n$errors lines changed in the data set\n";
  print "$rm bad lines removed\n";
  print "Scrubbed file written to: $outfile\n";
}
