# compareforecasts.R
#
# Plots a comparison of forecasts with and without JPI equation
#
library(MSBVAR)

load("noJPI.forecasts.RData")

load("forecasts.RData")


varnames <- colnames(Y.AFP.means)

# Modified plotting function -- this is a revised version of the one
# currently in MSBVAR.

"plot.forecasts" <-
function(x, cf.level, method=c("Sims-Zha2"), probs=c(0.16,0.84),
         component=1, xlab="", ylab="", ...)
{
    if(method=="Percentile"){
     m.forecast<-apply(x, 2, mean)
     quant<-apply(x, 2, quantile, probs=probs)
     vplus<-quant[1,]
     vminus<-quant[2,]
     forc.ci<-ts(t(rbind(m.forecast,vplus,vminus,cf.level)),
                 start=c(2005,4), freq=12)
 }
     if (method == "Sims-Zha2") {
         nsteps <- ncol(x)
         eigen.sum <- matrix(0, 1, nsteps)
#         for (i in 1:m^2) {
         decomp <- eigen(var(x), symmetric = T)
         W <- decomp$vectors
         lambda <- decomp$values
         gammak <- x * (W[component, ])
         gammak.quantiles <- t(apply(gammak, 2, quantile,
                                         probs = probs))
         m.forecast <- apply(x, 2, mean)
         quant <- m.forecast + gammak.quantiles
         forc.ci<-ts(cbind(m.forecast,quant, cf.level),
                     start=c(2005,4), freq=12)
         eigen.sum <- 100 * lambda/sum(lambda)
         cat("Eigen-vector percentages :", eigen.sum, "\n")

     }

     par(las=1)

     plot(forc.ci, ylab=ylab, xlab=xlab,
          axes=FALSE, plot.type="single", lty=c(rep(1,3), 2), ...)

     axis(1, at=c(2005.25, 2005.583, 2005.917),
          labels=c("April 2005","July 2005","Dec. 2005"))

     axis(2)
     box();
    }




pdf(file="compareforecasts.pdf", width=9, height=4)

par(mfrow=c(2,7), mai = c(0.35, 0.25, 0.15, 0.15),
    omi = c(0.25, 1.3, 0.25, 0.15), cex.lab=0.8, cex.axis=0.8)

for(i in 1:7)
{
 plot.forecasts(credibility.forecasts[,,i],
                cf.level=actual.data[,i],
                probs=c(0.16,0.84),
                main=varnames[i])
 if(i==1) mtext("JPI equation", side=2, line=3, adj=1, cex=0.9)
 abline(h=0)
}


for(i in 1:6)
{
 plot.forecasts(noJPI.forecasts[,,i],
                cf.level=actual.data[,i],
                probs=c(0.16,0.84))

 if(i==1) mtext("No JPI equation", side=2, line=3, adj=1, cex=0.9)
 abline(h=0)
}


dev.off()


# Compute Root MSE for the forecast errors.  Do this rather explicitly
# so we can keep track of things.  This could be done with fancy
# apply() and sweep() calls, but that is actually less efficient in R
# because of the issues with how apply is slow with lists and arrays
# that are more than 2D.  This use formula 15.3.2 from Lutkepohl
# (2005) for the asymptotic variance computation.

h <- 9

x <- sweep(credibility.forecasts, c(2,3), actual.data)

msecred <- array(0, c(m, m, h))
for(i in 1:dim(x)[1])
{
    msetmp <- matrix(0, m, m)
    for (j in 1:h)
    {
        msetmp <- msetmp + (1 + m*j/n)*tcrossprod(x[i,j,])
        msecred[,,j] <- msecred[,,j] + msetmp
    }

}

msecred <- msecred/dim(x)[1]


y <- sweep(noJPI.forecasts, c(2,3), actual.data[,1:6])

msenoJPI <- array(0, c(m-1, m-1, h))
for(i in 1:dim(y)[1])
{
    msetmp <- matrix(0, m-1,m-1)
    for (j in 1:h)
    {
        msetmp <- msetmp + (1 + (m-1)*j/n)*tcrossprod(y[i,j,])
        msenoJPI[,,j] <- msenoJPI[,,j] + msetmp
    }

}

msenoJPI <- msenoJPI/dim(y)[1]

# Find coverage probabilities for the posterior forecasts
coverage.probs <- function(x, component=1, probs=c(0.16, 0.84))
{
    nsteps <- ncol(x)
    eigen.sum <- matrix(0, 1, nsteps)

    decomp <- eigen(var(x), symmetric = T)
    W <- decomp$vectors
    lambda <- decomp$values
    gammak <- x * (W[component, ])
    gammak.quantiles <- t(apply(gammak, 2, quantile,
                                probs = probs))
    m.forecast <- apply(x, 2, mean)
    quant <- m.forecast + gammak.quantiles

#    eigen.sum <- 100 * lambda/sum(lambda)
#    cat("Eigen-vector percentages :", eigen.sum, "\n")

    value <- as.vector(x)
    upper <- as.vector(quant[,2])
    lower <- as.vector(quant[,1])

    p <- ifelse(value> lower & value < upper, 1, 0)
    return(p)
}

# clean up and exit
q(save="no")
