# fitmodels.R
# Fits the models / finds the peaks of the posteriors
#
# Patrick T. Brandt
# pbrandt@utdallas.edu
#
# 20070516 : Initial version
# 20071019 : Revised to use latest version of MSBVAR

# Load libraries
library(MSBVAR)

# Load the data and setup for the models
load("data_and_structure200705.RData")

# Define the models
model.list <- c("accountability", "bystander",
                "credibility", "follower")

data.list <- c("AFP", "REU")

type.list <- c("sums", "means")

set.seed(1986)


# Loop over the various data and model specifications and estimate the
# peaks of the posterior density for each.

for(i in 1:length(model.list))
{
    for (j in 1:length(data.list))
    {

        for(k in 1:length(type.list))
        {
            # Dynamically define the inputs and outputs for the models

            model.name.exog <- paste(model.list[i], data.list[j],
                                     type.list[k], "exog", sep=".")
            model.name.noexog <- paste(model.list[i], data.list[j],
                                     type.list[k], "nexog", sep=".")

            data.name <- paste("Y", data.list[j], type.list[k],
                               sep=".")
            ident.name <- paste(model.list[i], "A0", sep=".")

            # Estimate the models

            # Model with the exogenous variables.
            M1 <- szbsvar(window(get(data.name), end=c(2005,3)),
                          p=p, z=window(z2, end=c(2005, 3)),
                          lambda0=lambda0, lambda1=lambda1,
                          lambda3=lambda3, lambda4=lambda4,
                          lambda5=lambda5, mu5=mu5,
                          mu6=mu6,
                          qm=qm,
                          ident=get(ident.name))

            # Model without the exogenous variables
            M2 <- szbsvar(window(get(data.name), end=c(2005,3)),
                          p=p, z=NULL,
                          lambda0=lambda0, lambda1=lambda1,
                          lambda3=lambda3, lambda4=lambda4,
                          lambda5=lambda5, mu5=mu5,
                          mu6=mu6,
                          qm=qm,
                          ident=get(ident.name))

            # Assign to the correctly named objects for later access.
            assign(model.name.exog, M1)
            assign(model.name.noexog, M2)
            rm(M1, M2)


        }

    }
}

# Save results and exit
save.image("fittedmodels.RData")

q(save="no")
