# irfmodels-exog-posdiag.R
#
# Computes the impulse responses for the models WITH the exogenous
# variables.

# Patrick T. Brandt
# pbrandt@utdallas.edu
#
# 20070516 : Initial version
# 20070628 : Normalize diagonals to be positive
# 20070705 : updated to normalize around positive posterior mode;
#            dropped REU and sums data from this run.
# 20071019 : Revised to use latest version of MSBVAR

# Load libraries
library(MSBVAR)

# Load the data and fitted models
load("fittedmodels.RData")

# Main loop to sample the models' impulse responses based on the
# specifications and results from setup.R, fitmodels.R and
# samplemodels.R.

set.seed(1105)

for(i in 1:length(model.list))
{

            # Dynamically define the inputs and outputs for the models
    model.name <- paste(model.list[i], "AFP",
                        "means", "exog", sep=".")

    A0filename <- paste(model.name, "A0parallel.RData",
                        sep="")

    IRF.out <- paste(model.name, "IRF-posdiag", sep=".")

    fileout <- paste(IRF.out, ".RData", sep="")

    pdfout <- paste(IRF.out, ".pdf", sep="")

            # Read in the posterior sample
    load(file=A0filename)

            # Use the 1st chain of A0s
    A0 <- model.out[[1]]
    A0$W.posterior <- 0

    rm(model.out)
    gc()

        # Find median signs

    A0$ident[which(A0$ident==1)] <- sign(apply(A02mcmc(A0), 2,
                   median))

        # Compute impulse responses with pos diag
    assign("IRF.out", mc.irf(get(model.name), nsteps=24,
                             A0.posterior=A0,
                             sign.list=diag(A0$ident)))

        rm(A0)

        # Save results

    save(IRF.out, file=fileout, compress=TRUE)

        # Plot IRF results
    pdf(file=pdfout, width = 6, height=6)

    plot(IRF.out, varnames=colnames(Y.REU.sums),
         method=c("Sims-Zha2"), probs=c(0.16,0.84))

    dev.off()

        # Cleanup
    rm(IRF.out)
    gc()
}

# Exit
q(save="no")

