# posteriorfit-exog.R
#
# Computes the log MDDs for assessing posterior peak and Bayes factors
# for the models WITH the exogenous variables.

# Patrick T. Brandt
# pbrandt@utdallas.edu
#
# 20070517 : Initial version
# 20071019 : Revised to use latest version of MSBVAR

# Load libraries
library(MSBVAR)

# Load the data and fitted models
load("fittedmodels.RData")

# Main loop to compute log MDDs and other measures of in-sample fit.
# based on the specifications and results from setup.R, fitmodels.R
# and samplemodels.R.

# Build a table / matrix to hold the results
results1 <- results2 <- as.data.frame(matrix(0, nrow=prod(length(model.list),
                                  length(data.list),
                                  length(type.list)), ncol=12))

colnames(results1) <- colnames(results2) <- c("Model", "log.prior", "LLF",
                                              "logA+",
                                              "logMDD",paste("logA0k",
                                              1:7, sep="."))

# Set a counter
ct <- 1

set.seed(15)

for(i in 1:length(model.list))
{
    for (j in 1:length(data.list))
    {
        for(k in 1:length(type.list))
        {
            # Dynamically define the inputs and outputs for the models
            model.name <- paste(model.list[i], data.list[j],
                                type.list[k], "exog", sep=".")

            A0filename <- paste(model.name, "A0parallel.RData",
                                sep="")

            # Read in the posterior sample
            load(file=A0filename)

            # Compute posterior fits for each chain
            fit.name1 <- posterior.fit(get(model.name),
                                           A0.posterior.obj=model.out[[1]])

            fit.name2 <- posterior.fit(get(model.name),
                                           A0.posterior.obj=model.out[[2]])

            results1[ct,] <- c(model.name, round(unlist(fit.name1), 2))
            results2[ct,] <- c(model.name, round(unlist(fit.name2), 2))

            ct <- ct+1
            cat("Completed model : ", ct, "\n")

            # Cleanup
            rm(model.out)
            gc()
        }
    }
}

save(results1,results2, file="posteriorfit-exog.RData")

# Exit
q(save="no")

