# mergedata.R
# Merges aggregated KEDS Levant data with Peace index data

# Load the event data -- this was produced using the dataparse.R
# script that aggregates KEDS events to monthly event totals.


load("/Users/brandt/BCF/data/LEVANT19912007MonthlyMeansGoldstein.RData")

# Now, subset the events so we have the dates we need

AFP.means <- window(AFP.monthly, start=c(1996,4))
REU.means <- window(REU.monthly, start=c(1996,4))

load("/Users/brandt/BCF/data/LEVANT19912007MonthlySumsGoldstein.RData")

# Now, subset the events so we have the dates we need

AFP.sums <- window(AFP.monthly, start=c(1996,4))
REU.sums <- window(REU.monthly, start=c(1996,4))

# Load the peace index data
peace <-
    read.table("/Users/brandt/BCF/data/Peace_index_Updated_Jonly_Jan06.txt", header=T,
                    sep="\t",)

peace.ts <- ts(peace[,2:4], freq=12, start=c(1996,4))

# Impute missing opinion data using an ARIMA model.
# Look at ACF and PACF
acf(peace.ts[,"JPI"], na.action=na.pass)
pacf(peace.ts[,"JPI"], na.action=na.pass)
# Looks like an ARIMA (9,0,0)
arima.JPI.test <- arima(peace.ts[,"JPI"], order=c(9,0,0))
arima.JPI.predict <- arima(window(peace.ts[,"JPI"], end=c(2003,2)), order=c(9,0,0))
JPI.arima.interp <- predict(arima.JPI.predict, n.ahead=8)

# Now splice the ARIMA predictions to the original data
JPI.arima <- ts(c(window(peace.ts[,"JPI"], end=c(2003,2)), JPI.arima.interp$pred,
                window(peace.ts[,"JPI"], start=c(2003,11))),
                start=c(1996,4), freq=12)

peace.ts[,"JPI"] <- JPI.arima

# Now merge the two sets of series

# Merge the means and sums of events
AFP.means.data <- cbind(peace.ts, AFP.means)
REU.means.data <- cbind(peace.ts, REU.means)

AFP.sums.data <- cbind(peace.ts, AFP.sums)
REU.sums.data <- cbind(peace.ts, REU.sums)

# Update column names
colnames(AFP.means.data) <- c(colnames(peace.ts),
                              colnames(AFP.means))

colnames(REU.means.data) <- c(colnames(peace.ts),
                              colnames(REU.means))

colnames(AFP.sums.data) <- c(colnames(peace.ts),
                              colnames(AFP.sums))

colnames(REU.sums.data) <- c(colnames(peace.ts),
                              colnames(REU.sums))

# Save results
save(AFP.means.data,
     REU.means.data,
     AFP.sums.data,
     REU.sums.data,
     file="AFP_and_REU_96-07Goldstein.RData")
